@@ -42,7 +42,7 @@ tm_lines = function(col = tm_const(),
 					group = NA,
 					group.control = "check",
 					popup.vars = NA,
-					popup.format = list(),
+					popup.format = tm_label_format(),
 					hover = NA,
 					id = "",
 					options = opt_tm_lines(),
@@ -245,7 +245,6 @@ tm_lines = function(col = tm_const(),
 						lineend = lineend),
 		tpar = tmapTpar(),
 		plot.order = plot.order,
-		mapping.fun = "Lines",
 		mapping.args = options$mapping.args,
 		zindex = zindex,
 		group = group,
