@@ -18,7 +18,7 @@ tmapLeafletCompWidth.tm_title = function(comp, o) {
 
 
 #' @export
-tmapLeafletLegPlot.tm_title = function(comp, lf, o) {
+tmapLeafletCompPlot.tm_title = function(comp, lf, o) {
 	if (inherits(lf, "shiny.tag.list")) {
 		ncld <- length(lf[[1]])
 		lf[[1]] <- mapply(function(l, i) {
@@ -75,7 +75,7 @@ tmapLeafletCompWidth.tm_compass = function(comp, o) {
 
 
 #' @export
-tmapLeafletLegPlot.tm_compass = function(comp, lf, o) {
+tmapLeafletCompPlot.tm_compass = function(comp, lf, o) {
 	lf %>% leafem::addLogo(system.file(paste0("img/compass_", comp$type, ".png"), package = "tmap"), position = leaflet_pos(comp$position), width = 120, height = 120)
 }
 
@@ -100,7 +100,7 @@ tmapLeafletCompWidth.tm_scalebar = function(comp, o) {
 
 
 #' @export
-tmapLeafletLegPlot.tm_scalebar = function(comp, lf, o) {
+tmapLeafletCompPlot.tm_scalebar = function(comp, lf, o) {
 	lf %>% leaflet::addScaleBar(position = leaflet_pos(comp$position))
 }
 
@@ -126,7 +126,7 @@ tmapLeafletCompWidth.tm_credits = function(comp, o) {
 
 
 #' @export
-tmapLeafletLegPlot.tm_credits = function(comp, lf, o) {
+tmapLeafletCompPlot.tm_credits = function(comp, lf, o) {
 	#lf %>% leafem::addLogo(system.file(paste0("img/credits_", comp$type, ".png"), package = "tmsap"), src = "local", position = paste(unlist(comp$position[c("pos.v", "pos.h")]), collapse = ""), width = 120, height = 120)
 	#message("tm_credits not implemented yet for view mode")
 	lf %>% leaflet::addTiles(urlTemplate = "", attribution = comp$text)
@@ -152,7 +152,7 @@ tmapLeafletCompWidth.tm_mouse_coordinates = function(comp, o) {
 
 
 #' @export
-tmapLeafletLegPlot.tm_mouse_coordinates = function(comp, lf, o) {
+tmapLeafletCompPlot.tm_mouse_coordinates = function(comp, lf, o) {
 	lf %>% leafem::addMouseCoordinates()
 }
 
@@ -161,6 +161,8 @@ tmapLeafletLegPlot.tm_mouse_coordinates = function(comp, lf, o) {
 #' @export
 tmapLeafletCompPrepare.tm_minimap = function(comp, o) {
 	comp$show = TRUE
+	comp$height = 20 * comp$height
+	comp$width = 20 * comp$width
 
 	extra = comp[setdiff(intersect(names(comp), names(formals(leaflet::addMiniMap))), c("position", "map"))]
 
@@ -173,6 +175,8 @@ tmapLeafletCompPrepare.tm_minimap = function(comp, o) {
 
 #' @export
 tmapLeafletCompHeight.tm_minimap = function(comp, o) {
+
+
 	comp
 }
 
@@ -183,7 +187,7 @@ tmapLeafletCompWidth.tm_minimap = function(comp, o) {
 
 
 #' @export
-tmapLeafletLegPlot.tm_minimap = function(comp, lf, o) {
+tmapLeafletCompPlot.tm_minimap = function(comp, lf, o) {
 	comp$args$tiles = if (comp$specified_tiles) {
 		comp$server
 	} else if (length(.TMAP_LEAFLET$tiles)) {
@@ -191,7 +195,7 @@ tmapLeafletLegPlot.tm_minimap = function(comp, lf, o) {
 	} else {
 		o$basemap.server[1]
 	}
-	lf2 = do.call(addMiniMap, c(list(map = lf), comp$args))
+	lf2 = do.call(addMiniMap, c(list(map = lf, position = leaflet_pos(comp$position)), comp$args))
 	if (!comp$specified_tiles && (length(comp$args$tiles) > 0)) {
 		lf2 <- lf2 %>%
 			htmlwidgets::onRender("
@@ -238,7 +242,7 @@ tmapLeafletCompWidth.tm_logo = function(comp, o) {
 }
 
 #' @export
-tmapLeafletLegPlot.tm_logo = function(comp, lf, o) {
+tmapLeafletCompPlot.tm_logo = function(comp, lf, o) {
 	ws = c(rev(cumsum(vapply(comp$logo, function(l)l$iconWidth,FUN.VALUE = numeric(1)) + 10))[-1], 0)
 
 	for (i in 1:length(comp$logo)) {
@@ -250,25 +254,42 @@ tmapLeafletLegPlot.tm_logo = function(comp, lf, o) {
 
 
 #' @export
-tmapLeafletCompPrepare.tm_inset = function(comp, o) {
-	comp$show = FALSE
-	comp
-}
-
-
-#' @export
-tmapLeafletCompHeight.tm_inset = function(comp, o) {
+tmapLeafletCompPrepare.tm_inset_image = function(comp, o) {
+	comp$file = comp$x
+	comp = tmapLeafletCompPrepare.tm_logo(comp, o)
+	class(comp) = c("tm_logo", class(comp))
 	comp
 }
 
 #' @export
-tmapLeafletCompWidth.tm_inset = function(comp, o) {
+tmapLeafletCompPrepare.tm_inset_grob = function(comp, o) {
+	height = 20 * comp$height
+	width = 20 * comp$width
+
+	grob.dim = c(width=width, height=height, render.width=width, render.height=height)
+
+	comp$logo = list(grob2icon(comp$x, grob.dim = grob.dim, just = c(0.5, 0.5)))
+	comp$logo = lapply(comp$logo, function(x){
+		scale = height / x$iconHeight
+		x$iconWidth = unname(x$iconWidth * scale)
+		x$iconHeight = unname(x$iconHeight * scale)
+		x$iconAnchorX = unname(x$iconAnchorX * scale)
+		x$iconAnchorY = unname(x$iconAnchorY * scale)
+		x
+	})
+
+	comp$asp = vapply(comp$logo, function(lg) {
+		lg$iconWidth / lg$iconHeight
+	}, FUN.VALUE = numeric(1))
+	comp$show = TRUE
+	class(comp) = c("tm_logo", class(comp))
 	comp
+
 }
 
 #' @export
-tmapLeafletLegPlot.tm_inset = function(comp, lf, o) {
-	lf
+tmapLeafletCompPrepare.tm_inset_gg = function(comp, o) {
+	rlang::check_installed("ggplot2", reason = "for plotting ggplot2 charts")
+	comp$x = ggplot2::ggplotGrob(comp$x)
+	tmapLeafletCompPrepare.tm_inset_grob(comp, o)
 }
-
-
