@@ -52,7 +52,8 @@
 #' Journal of Statistical Software, 84(6), 1-39, \doi{10.18637/jss.v084.i06}
 #' @export
 tmap_mode = function(mode = NULL) {
-	set_mode(mode, show.messages = get("tmapOptions", envir = .TMAP)$show.messages, type = "set")
+	type = if (is.null(mode)) "get" else "set"
+	set_mode(mode, show.messages = get("tmapOptions", envir = .TMAP)$show.messages, type = type)
 }
 
 
@@ -70,65 +71,52 @@ rtm = function() {
 
 
 set_mode = function(mode = NULL, show.messages = FALSE, type = "set") {
-	current.mode = getOption("tmap.mode")
+	mode_now = getOption("tmap.mode")
 
 	tOpt = get("tmapOptions", envir = .TMAP)
 	show.messages = tOpt$show.messages
 
 	modes = get_modes()
-	id = match(current.mode, modes)
+	id = match(mode_now, modes)
 
-	if (type == "toggle") {
-		mode = .TMAP$mode_last
-	} else if (type == "rotate") {
-		id = id + 1L
-		if (id > length(modes)) id = 1L
-		mode = modes[id]
+	arrow = length(modes) > 2
+
+	if (type == "get") {
+		mode_next = mode_now
+		id_next = id
+	} else if (type == "set") {
+		mode_next = rlang::arg_match0(mode, modes)
+		id_next = match(mode_next, modes)
+	} else if (type == "toggle") {
+		mode_next = .TMAP$mode_last
+		id_next = match(mode_next, modes)
+	} else {
+		id_next = id + 1L
+		if (id_next > length(modes)) id_next = 1L
+		mode_next = modes[id_next]
 	}
 
 	modes_str = paste0("{.val ", modes, "}")
-	modes_str[id] = paste0("{.strong ", modes_str[id], "}")
-	rotate_str = paste(modes_str, collapse = " -> ")
+	modes_str[id_next] = paste0("{.strong ", modes_str[id_next], "}")
+	rotate_str = paste(modes_str, collapse = ifelse(arrow, " -> ", " - "))
 
-
-	if (is.null(mode)) {
-		others = setdiff(modes, current.mode)
-		tmode = .TMAP$mode_last
-		if (length(modes) == 2) {
-			cli::cli_inform(c(
-				"i" = "Current tmap mode is {.val {current.mode}}.",
-				"i" = "Call {.run tmap::ttm()} to switch to mode {.val {tmode}}."))
-		} else {
-			cli::cli_inform(c(
-				"i" = "Current tmap mode is {.val {current.mode}}.",
-				"i" = "Call {.run tmap::ttm()} to switch to mode {.val {tmode}}.",
-				"i" = paste0("Call {.run tmap::rtm()} to rotate between all modes: ", rotate_str)
-			))
-		}
-
-	} else {
-		rlang::arg_match0(mode, modes)
-		if (current.mode != mode) .TMAP$mode_last = current.mode
-		options(tmap.mode = mode)
+	if (mode_now != mode_next) {
+		.TMAP$mode_last = mode_now
+		options(tmap.mode = mode_next)
 		fill_providers()
-		if (show.messages) {
-			if (type == "set") {
-				cli::cli_inform(c(i = "tmap mode set to {.val {mode}}."))
-			} else if (type == "toggle") {
-				cli::cli_inform(c("i" = "tmap mode set to {.val {mode}}.",
-								  "i" = "switch back to {.val {current.mode}} mode with {.run tmap::ttm()}"))
-			} else {
-				nid = id + 1L
-				if (nid > length(modes)) nid = 1L
-				nmode = modes[nid]
-				str = paste0("rotate cycle ", rotate_str, " with {.run tmap::rtm()}")
-				cli::cli_inform(c("i" = "tmap mode rotated to {.val {modes[id]}}.",
-								  "i" = str))
-
-			}
-		}
 	}
-	invisible(current.mode)
+
+	if (show.messages) {
+		str1 = paste0("tmap modes ", rotate_str)
+		str2 = paste0(ifelse(arrow, "rotate with {.run tmap::rtm()}", ""),
+					 ifelse(arrow, "switch to {.str {mode_now}} ", "toggle "),
+					 "with {.run tmap::ttm()}")
+
+		cli::cli_inform(c("i" = str1))
+		cli::cli_inform(c("i" = str2), .frequency = "once", .frequency_id = paste0("mode", ifelse(arrow, "_rotate", "toggle")))
+	}
+
+	invisible(mode_now)
 }
 
 
@@ -147,9 +135,10 @@ get_modes = function() {
 
 #' Set the design mode
 #'
-#' When the so-called "design mode" is enabled, inner and outer margins,
-#' legend position, and aspect ratio are shown explicitly in plot mode.
-#' Also, information about aspect ratios is printed in the console.
+#' When the so-called "design mode" is enabled,
+#' the composition of the plot is shown explicitly in plot mode.
+#' The used color codings is printed in the console as well as information about plot size and aspect ratio.
+#'
 #' This function sets the global option `tmap.design.mode`.
 #' It can be used as toggle function without arguments.
 #'
