@@ -29,10 +29,10 @@
 					 			leaflet.options = list())),
 
 		crs = NA,
+		bbox = NULL,
 
 		# facets
 		facet.max = 64, # was max.facets
-		facet.flip = FALSE,
 		free.scales = NULL, # for backward compatibility: if this value is set, it will be used to impute the free arguments in the layer functions
 
 		# spatial object class specific options
@@ -205,12 +205,15 @@
 			fun = NULL,
 			scientific = FALSE,
 			digits = NA,
-			big.num.abbr = c(mln = 6, bln = 9),
+			interval.disjoint = TRUE,
+			big.num.abbr = c(mln = 6, bln = 9, trn = 12, qdn = 15, qnt = 18),
 			prefix = "",
 			suffix = "",
-			text.separator = "to",
-			text.less.than = c("Less", "than"),
-			text.or.more = c("or", "more"),
+			text.separator = "-",
+			text.less.than = "<",
+			text.less.than_as.prefix = TRUE,
+			text.or.more = "\u2265",
+			text.or.more_as.prefix = TRUE,
 			text.align = NA,
 			text.to.columns = FALSE,
 			html.escape = TRUE
@@ -235,7 +238,7 @@
 		frame.color = NA,
 		frame.alpha = 1,
 		frame.lwd = 1,
-		frame.r = 2,
+		frame.r = NA,
 		frame.double_line = FALSE,
 
 
@@ -248,17 +251,13 @@
 		between_margin = 0.5,
 		panel.margin = c(xtab = 0.4, 0),
 
-		grid.mark.height = 2,
-		xylab.height = 1.25,
-		coords.height = 1.25,
-
 		# xlab, ylab
 		xlab.show = FALSE,
 		xlab.text = "",
 		xlab.size = 1,
 		xlab.color = "black",
 		xlab.rotation = 0,
-		xlab.space = 0,
+		xlab.space = 0.5,
 		xlab.fontface = NULL,
 		xlab.fontfamily = NULL,
 		xlab.alpha = 1,
@@ -269,7 +268,7 @@
 		ylab.size = 1,
 		ylab.color = "black",
 		ylab.rotation = 0,
-		ylab.space = 0,
+		ylab.space = 0.5,
 		ylab.fontface = NULL,
 		ylab.fontfamily = NULL,
 		ylab.alpha = 1,
@@ -294,7 +293,7 @@
 		# text
 		text.fontface = "plain",
 		text.fontfamily = "",
-		text.alpha = 1,
+		r = 2,
 
 		component.position = list('in' = tm_pos_in(pos.h = "left", pos.v = "top",
 											  align.h = "left", align.v = "top", just.h = "left", just.v = "top"),
@@ -315,7 +314,7 @@
 		component.frame.color = NA,
 		component.frame.alpha = 1,
 		component.frame.lwd = 1,
-		component.frame.r = 2,
+		component.frame.r = NA,
 
 		component.bg = TRUE,
 		component.bg.color = "white",
@@ -323,7 +322,6 @@
 
 		# legend
 		legend.show = TRUE,
-		legend.design = "standard",
 		legend.orientation = "portrait",
 		legend.position = tm_pos_auto_out(cell.h = "right", cell.v = "bottom",
 										  pos.h = "left", pos.v = "top",
@@ -346,6 +344,8 @@
 		legend.ylab.size = 0.9,
 		legend.ylab.fontface = NULL,
 		legend.ylab.fontfamily = NULL,
+		legend.xlab.rot = 0,
+		legend.ylab.rot = 0,
 		legend.ylab.alpha = 1,
 		legend.text.color = NA,
 		legend.text.size = 0.7,
@@ -356,15 +356,15 @@
 		legend.frame.color = NA,
 		legend.frame.alpha = 1,
 		legend.frame.lwd = 1,
-		legend.frame.r = 2,
+		legend.frame.r = NA,
 		legend.bg = TRUE,
 		legend.bg.color = "white",
 		legend.bg.alpha = 1,
 		legend.only = FALSE,
 		legend.absolute_fontsize = 14,
-		legend.settings.standard.portrait = list(item.height = c(rect = 1.2, symbols = 1, gradient = 3, lines = 1.2, text = 1.2, bivariate = 1.2),
+		legend.settings.portrait = list(item.height = c(rect = 1.2, symbols = 1, gradient = 3, lines = 1.2, text = 1.2, bivariate = 1.2),
 												 item.width = c(rect = 1.2, symbols = 1, gradient = 1.2, lines = 1.2, text = 3, bivariate = 1.2),
-												 item.r = 2,
+												 item.r = NA,
 												 item.space = c(rect = 0.2, symbols = 0.2, gradient = 0, lines = 0.2, text = 0.2, bivariate = 0),
 												 item.na.height = c(rect = NA, symbols = NA, gradient = 1.2, lines = NA, text = NA, bivariate = NA),
 												 item.na.width = c(rect = NA, symbols = NA, gradient = 1.2, lines = NA, text = NA, bivariate = NA),
@@ -376,15 +376,15 @@
 												 title.align = c(bivariate = "right", "left"),
 												 xlab.align = "left",
 												 ylab.align = "center",
-												 ticks = list(rect = list(), symbols = list(), gradient = list(c(1, 1.5)), lines = list(), text = list(), bivariate = list()),
+												 ticks = list(rect = list(), symbols = list(), gradient = list(c(0.85, 1.1)), lines = list(), text = list(), bivariate = list()),
 												 ticks.disable.na = c(rect = FALSE, symbols = FALSE, gradient = TRUE, lines = FALSE, text = FALSE, bivariate = TRUE),
 												 ticks.col = NA,
-												 ticks.lwd = 1.5,
+												 ticks.lwd = 1,
 												 margins = c(0.4, 0.4, 0.4, 0.4),
-												 item_text.margin = 0.25),
-		legend.settings.standard.landscape = list(item.height = c(rect = 1, symbols = 1, gradient = 1.2, lines = 1, text = 1),
+												 item_text.margin = c(gradient = 0.5, 0.25)),
+		legend.settings.landscape = list(item.height = c(rect = 1, symbols = 1, gradient = 1.2, lines = 1, text = 1),
 												  item.width = c(rect = 6, symbols = 3, gradient = 6, lines = 6, text = 6),
-												  item.r = 2,
+												  item.r = NA,
 												  item.space = c(rect = 0.2, symbols = 0.3, gradient = 0, lines = 0.2, text = 0.2),
 												  item.na.height = c(rect = NA, symbols = NA, gradient = 2, lines = NA, text = NA),
 												  item.na.width = c(rect = NA, symbols = NA, gradient = 4, lines = NA, text = NA),
@@ -397,10 +397,10 @@
 												  title.align = c(bivariate = "right", "left"),
 												  xlab.align = "left",
 												  ylab.align = "center",
-												  ticks = list(rect = list(), symbols = list(), gradient = list(c(1, 1.2)), lines = list(), text = list()),
+												  ticks = list(rect = list(), symbols = list(), gradient = list(c(0.85, 1.1)), lines = list(), text = list()),
 												  ticks.disable.na = c(rect = FALSE, symbols = FALSE, gradient = TRUE, lines = FALSE, text = FALSE),
 												  ticks.col = NA,
-												  ticks.lwd = 1.5,
+												  ticks.lwd = 1,
 												  margins = c(0.4, 0.4, 0.4, 0.4),
 												  item_text.margin = 0.25),
 
@@ -456,7 +456,7 @@
 		chart.frame.color = NA,
 		chart.frame.alpha = 1,
 		chart.frame.lwd = 1,
-		chart.frame.r = 2,
+		chart.frame.r = NA,
 		chart.bg = TRUE,
 		chart.bg.color = "white",
 		chart.bg.alpha = 1,
@@ -473,7 +473,7 @@
 		title.frame.color = NA,
 		title.frame.alpha = 1,
 		title.frame.lwd = 1,
-		title.frame.r = 2,
+		title.frame.r = NA,
 		title.position = tm_pos_out(cell.h = "center", cell.v ="top", pos.h = "left", pos.v = "top", align.h = "left", align.v = "top", just.h = "left", just.v = "top"),
 		title.width = NA,
 		credits.size = .7,
@@ -505,12 +505,6 @@
 		logo.between_margin = 0.2,
 		logo.position = tm_pos_in(pos.h = "right", pos.v = "bottom", align.h = "right", align.v = "top", just.h = "left", just.v = "top"),
 
-		inset_map.height = 7,
-		inset_map.width = 7,
-		inset_map.margins = c(0.2, 0.2, 0.2, 0.2),
-		inset_map.between_margin = 0.2,
-		inset_map.position = tm_pos_in(pos.h = "right", pos.v = "bottom", align.h = "right", align.v = "top", just.h = "left", just.v = "top"),
-		inset_map.frame = TRUE,
 
 		inset.height = 3,
 		inset.width = 3,
@@ -522,6 +516,31 @@
 		inset.bg.color = "#ffffff",
 		inset.bg.alpha = 1,
 
+		inset.box_frame = TRUE,
+		inset.box_frame.color = "#ee2211",
+		inset.box_frame.alpha = 1,
+		inset.box_frame.lwd = 2,
+		inset.box_frame.lty = "solid",
+		inset.box_bg = FALSE,
+		inset.box_bg.color = "#ffffff",
+		inset.box_bg.alpha = 1,
+
+		inset.main_frame = TRUE,
+		inset.main_frame.r = NA,
+		inset.main_frame.color = NA,
+		inset.main_frame.alpha = 1,
+		inset.main_frame.lwd = 2,
+
+		inset_map.height = 7,
+		inset_map.width = 7,
+		inset_map.margins = c(0.2, 0.2, 0.2, 0.2),
+		inset_map.between_margin = 0.2,
+		inset_map.position = tm_pos_in(pos.h = "right", pos.v = "bottom", align.h = "right", align.v = "top", just.h = "left", just.v = "top"),
+		inset_map.frame = FALSE,
+
+		inset_tmap.height = 7,
+		inset_tmap.width = 7,
+
 		inset_grob.height = 7,
 		inset_grob.width = 7,
 
@@ -530,13 +549,13 @@
 
 		scalebar.breaks = NULL,
 		scalebar.width = 12,
-		scalebar.allow_clipping = TRUE,
+		scalebar.allow_clipping = FALSE,
 		scalebar.text.size = .5,
 		scalebar.text.color = NA,
 		scalebar.text.fontface = NULL,
 		scalebar.text.fontfamily = NULL,
-		scalebar.color.dark = "black",
-		scalebar.color.light = "white",
+		scalebar.color.dark = NA,
+		scalebar.color.light = NA,
 		scalebar.lwd = 1,
 		scalebar.size = NULL,
 		scalebar.margins = c(0.01,0.01,0.01,0.01),
@@ -587,6 +606,13 @@
 		minimap.server = NA,
 		minimap.toggle = TRUE,
 		minimap.position = tm_pos_in(pos.h = "right", pos.v = "bottom", align.h = "right", align.v = "top", just.h = "left", just.v = "top"),
+		minimap.height = 7,
+		minimap.width = 7,
+		minimap.margins = c(0.2, 0.2, 0.2, 0.2),
+		minimap.between_margin = 0.2,
+		minimap.frame = FALSE,
+		minimap.bg = TRUE,
+
 
 		panel.show = NA, # depends on type: TRUE for facets
 		panel.labels = NA,
@@ -602,7 +628,7 @@
 		panel.label.frame.color = NA,
 		panel.label.frame.alpha = 1,
 		panel.label.frame.lwd = 1,
-		panel.label.frame.r = 2,
+		panel.label.frame.r = NA,
 		panel.label.height = 1,
 		panel.label.rot = c(90, 0, 270, 0),
 
@@ -614,7 +640,9 @@
 		earth_boundary.color = NA,
 		earth_boundary.lwd = 1,
 		earth_datum = "OGC:CRS84",
+		space = TRUE,
 		space.color = "#ffffff",
+		space_overlay = NA,
 
 		check_and_fix = FALSE,
 
@@ -685,7 +713,7 @@ styles = list(
 		legend.title.size = 0.9,
 		legend.frame = FALSE,
 		legend.frame.r = 0,
-		legend.settings.standard.portrait = list(item.height = c(rect = 1, symbols = 1, gradient = 1, bivariate = 1),
+		legend.settings.portrait = list(item.height = c(rect = 1, symbols = 1, gradient = 1, bivariate = 1),
 												 item.width = c(rect = 1, symbols = 1, gradient = 1.2, bivariate = 1),
 												 item.r = 0,
 												 item.space = c(rect = 0, symbols = 0, gradient = 0, bivariate = 0),
@@ -699,7 +727,7 @@ styles = list(
 												 ticks.lwd = 1.5,
 												 margins = c(0.4, 0.4, 0.4, 0.4),
 												 item_text.margin = 0.25),
-		legend.settings.standard.landscape = list(item.height = c(rect = 1, symbols = 1, gradient = 1.2),
+		legend.settings.landscape = list(item.height = c(rect = 1, symbols = 1, gradient = 1.2),
 												  item.width = c(rect = 6, symbols = 3, gradient = 6),
 												  item.r = 0,
 												  item.space = c(rect = 0.2, symbols = 0.3, gradient = 0),
@@ -753,7 +781,7 @@ styles = list(
 		legend.frame = TRUE,
 		legend.bg.color = "grey90",
 		frame = FALSE,
-		earth_boundary = TRUE,
+		earth_boundary = FALSE,
 		basemap.server = "Esri.NatGeoWorldMap",
 		basemap.alpha = 1),
 	cobalt = list(bg.color = "#002240",
@@ -762,9 +790,8 @@ styles = list(
 				  space.color = "#002240",
 				  value.const = list(fill.polygons = "#0088FF",
 				  				   fill = "#FF9D00",
-				  				   col.lines = "#FFEE80",
 				  				   col.text = "white",
-				  				   col = "#002240",
+				  				   col = "#FFEE80",
 				  				   bgcol.labels_highlighted = "#002240",
 				  				   bgcol = "#00000000"),
 				  value.na = list(
